@@ -52,8 +52,8 @@ class Vault: public QObject {
 
     Q_PROPERTY(PlasmaVault::Device device READ device)
 
-    Q_PROPERTY(QString mountPoint       READ mountPoint    NOTIFY mountPointChanged)
-    Q_PROPERTY(VaultInfo::Status status READ status        NOTIFY statusChanged)
+    Q_PROPERTY(QString mountPoint       READ mountPoint NOTIFY mountPointChanged)
+    Q_PROPERTY(VaultInfo::Status status READ status     NOTIFY statusChanged)
 
     Q_PROPERTY(bool isInitialized READ isInitialized NOTIFY isInitializedChanged)
     Q_PROPERTY(bool isOpened      READ isOpened      NOTIFY isOpenedChanged)
@@ -62,7 +62,7 @@ class Vault: public QObject {
     Q_PROPERTY(QString name       READ name    NOTIFY nameChanged)
     Q_PROPERTY(QString message    READ message NOTIFY messageChanged)
 
-    Q_PROPERTY(QStringList activities  READ activities  NOTIFY activitiesChanged)
+    Q_PROPERTY(QStringList activities  READ activities      NOTIFY activitiesChanged)
     Q_PROPERTY(bool        isOfflineOnly READ isOfflineOnly NOTIFY isOfflineOnlyChanged)
 
 public:
@@ -75,6 +75,8 @@ public:
 
     FutureResult<> create(const QString &name, const MountPoint &mountPoint,
                           const Payload &payload);
+    FutureResult<> import(const QString &name, const MountPoint &mountPoint,
+                          const Payload &payload);
 
     FutureResult<> open(const Payload &payload);
     FutureResult<> close();
@@ -86,6 +88,9 @@ public:
 
     VaultInfo info() const;
 
+    // TODO: Replace this with shared_ptr and enable_shared_from_this?
+    void scheduleDeletion();
+
 public Q_SLOTS:
     QString message() const;
     VaultInfo::Status status() const;
